entrypoint

Macro entrypoint 

macro_rules! entrypoint {
    ($local_laws:path $(,)?) => { ... };
}
Define the entrypoint of a local laws proof program.

Parameters

  • $local_laws: Path to the local law type to execute. The type must implement crate::LocalLaws.

Requirements

  • The sp1-zkvm crate must be available in the crate calling this macro.

Example

The main.rs of a local laws proof program:

#![no_main]
use delta_local_laws::example::MinMaxSpendingLocalLaw;
delta_local_laws::entrypoint!(MinMaxSpendingLocalLaw);